function [C,Cf,diff,UB,rho0,r0] = Bur2Constant(r,rho0,r0,Cini)

%Version 1.0
%Copyright 28 December 2012 by Alan R. Parry
%Permission is granted to all to use this software for non-commercial uses
%only. Permission for commercial use must be obtained in writing from the
%author.
%
%This function computes the constant mass profile that best fits a Burkert
%mass profile of central density "rho0" (in units of solar masses per
%cubic parsec) and core radius "r0" (in units of parsecs).  All of which
%are computed on the radial mesh, "r".  The different fits are
%parameterized by the value of the constant mass profile.  For convenience
%and consistency in the computations, the input parameters rho0 and r0 are
%converted into units of inverse light years squared and light years
%respectively.  The initial value of the mass can be set by the optional
%input parameter "Cini".  If no Cini value is specified, C is set to half
%the total Burkert mass at the last point of r by default.
%
%This program works on the same shifting grid method as Bur2EKGwUp only
%this time the grid is set along the constant value of the mass profile.
%
%The output parameters are the following.  The parameter "C" is the value
%of the constant mass.  The function "Cf" is the constant mass profile.
%"diff" is the approximation of the L2 norm of the difference between the
%Burkert profile and the constant mass profile computed discretely along
%the given mesh, r.  "UB" is a 2 row matrix containing the Burkert energy
%density profile rho (row 1) and the Burkert mass profile M (row 2)
%computed respectively in units of inverse light years squared and light
%years. Finally, the output parameters, "rho0" and "r0", are the Burkert
%central density and core radius converted to units of inverse light years
%squared and light years.

%Define Burkert profile.

[rho,M,rho0,r0] = Burkert(r,rho0,r0);

K = length(M)-1;
dr = r(2);

UB(1,1:K+1) = rho;
UB(2,1:K+1) = M;

%Define grid size, initial center, and step.

s = 3;

Grid = zeros(2,s);

if nargin >= 4
    
    cntr = Cini;
    
else
    
    cntr = 1/2*M(K+1);
    
end

step = 1/2*M(K+1);


%Define initial grid.

cp = ceil(s/2);

for k = 1:s
    
    Grid(1,k) = cntr + (k-cp)*step;
    
end

%Compute the errors for each C.

for k = 1:s
    
    C = Grid(1,k);
    
    diff2 = zeros(1,K+1);
    
    for j = 1:K+1
        diff2(j) = (C - M(j))^2*dr;
    end
    
    Grid(2,k) = sum(diff2);
    
end

[~,indx] = min(Grid(2,:));
idx = Grid(1,indx);

%Shift and shrink grid to home in on the minimum.

while step > 2^(-10)*M(K+1)
    
    while idx ~= cntr
        
        %Redefine grid and center.
        
        cntr = idx;
        
        Grid1 = zeros(2,s);
        
        for k = 1:s
            
            Grid1(1,k) = cntr + (k-cp)*step;
            
        end
        
        for j = 1:s
            for k = 1:s
                if Grid1(1,j) == Grid(1,k);
                    
                    Grid1(2,j) = Grid(2,k);
                    
                end
            end
        end
        
        %Compute the errors of the new grid.
        
        for k = 1:s
            if Grid1(2,k) == 0
                
                C = Grid1(1,k);
                
                diff2 = zeros(1,K+1);
                
                for j = 1:K+1
                    
                    diff2(j) = (C - M(j))^2*dr;
                    
                end
                
                Grid1(2,k) = sum(diff2);
                
            end
        end
        
        Grid = Grid1;
        
        %Compute the minimum of the errors on this grid.
        
        [~,indx] = min(Grid(2,:));
        idx = Grid(1,indx);
        
    end
    
    step = step/2;
    
    %Redefine grid and center
    
    cntr = idx;
    Grid1 = zeros(2,s);
    
    for k = 1:s
        
        Grid1(1,k) = cntr + (k-cp)*step;
        
    end
    
    %Compute the errors of the new grid.
    
    for k = 1:s
        if k == cp
            
            Grid1(2,k) = Grid(2,k);
            
        else
            
            C = Grid1(1,k);
                
            diff2 = zeros(1,K+1);
                
            for j = 1:K+1
                    
                diff2(j) = (C - M(j))^2*dr;
                    
            end
                
            Grid1(2,k) = sum(diff2);
            
        end
    end
    
    Grid = Grid1;
    
    %Compute the minimum of the errors on this grid.
    
    [~,indx] = min(Grid(2,:));
    idx = Grid(1,indx);
    
end

%Recompute the minimum function

C = idx;
diff = Grid(2,indx);
Cf = zeros(1,K+1);

for k = 1:K+1
    Cf(k) = C;
end

%Plot constant function comparison.

figure(1)
plot(r,M,'--r',r,Cf,'-b')
xlabel('r')
ylabel('Mass')
title('Mass profiles for some galaxy.')

end