function [err,Upsilon,mu0,U] = BurEKGdiff(r,M,rh,m,state)

%Version 1.0
%Copyright 28 December 2012 by Alan R. Parry
%Permission is granted to all to use this software for non-commercial uses
%only. Permission for commercial use must be obtained in writing from the
%author.
%
%This function computes the L2 norm (technically its square) of the
%differences between the mass profile "M" and the "state"^th excited state
%mass profile of half mass radius "rh" and total mass "m."  It computes
%this norm approximately by doing so discretely on the mesh r.
%
%The output parameters are as follows.  "err" is the value of the
%difference between the two mass profiles.  "Upsilon" and "mu0" are the
%values of Upsilon and mu_0 corresponding to rh, m, and state.  "U" is a 5
%row matrix containing the values of the functions f (row 1), p (row 2), 
%V (row 3), M (row 4), and muV (row 5) of the state^th excited state
%corresponding to rh and m.  The functions, f, p, V, and M are as defined
%in the paper, muV is equal to 4pi r^2 mu, where mu is the energy density.
%
%Since this uses CreateState which only works for the ground through fifth
%excited, tenth excited, and twentieth excited states, this function only
%works for those states as well.

%Define parameters.

K = length(r)-1;
dr = r(2);

%Compute the appropriate state.

[Upsilon,mu0,U] = CreateState(dr,rh,m,state);
N = length(U) - 1;

%Compute the L2 norm of the difference between the two mass profiles.  This
%has to be done on the same mesh that the Burkert profile is defined on, so
%first we compute the static state on the appropriate mesh.  The only
%difference between the meshes is the length of the interval they are
%computed on, the size of dr is the already the same.  The static state
%mass is too long, we simply truncate it to compute the difference.  If
%it is too short, then since f and p are approximately 0 on the outer
%boundary anyway, we attach on enough 0s of f and p to lengthen the
%interval.
%
%The function NCEKG_metric is a subroutine from a different set of
%software, but performed what we needed here as well so we used it. The
%last input parameter in the NCEKG_metric is a reflectivity constant and
%its value is irrelevant in our case.  We use the value of -1 simply to
%utilize the subroutine and make it run.  Its value makes no difference to
%the computation in this setting.

if N < K
    
    ft = zeros(1,K+1);
    pt = zeros(1,K+1);
    
    ft(1:N+1) = U(1,1:N+1);
    pt(1:N+1) = U(2,1:N+1);
    
    for k = N+2:K+1
        
        ft(k) = 0;
        pt(k) = 0;
        
    end
    
    [Vt,Mt,muVt] = NCEKG_metric(ft,pt,r,Upsilon,mu0,-1);
    
    U = zeros(5,K+1);
    U(1,1:K+1) = ft;
    U(2,1:K+1) = pt;
    U(3,1:K+1) = Vt;
    U(4,1:K+1) = Mt;
    U(5,1:K+1) = muVt;
    
end

%We now compute the actual L2 norm of the difference between the mass
%profiles.

diff2 = zeros(1,K+1);

for k = 1:K+1
    diff2(k) = (U(4,k) - M(k))^2*dr;
end

err = sum(diff2);

%We plot here both profiles for reference and so that we can see that the
%program is actually working.

figure(2)
plot(r(1:K+1),M(1:K+1),'--r',r(1:K+1),U(4,1:K+1),'-b')
xlabel('r')
ylabel('Mass')
title('Mass profiles for')


end