function [F,H,V,M,muV] = NCEKG_computestatic(F0,V0,omegamult,r,Upsilon,mu0)

%Version 1.0
%Copyright 28 December 2012 by Alan R. Parry
%Permission is granted to all to use this software for non-commercial uses
%only. Permission for commercial use must be obtained in writing from the
%author.
%
%This function solves the ODEs of the static spherically symmetric version
%of the EKG equations with the parameters F(0)="F0", V(0)="V0", omega =
%"omegamult"*Upsilon, "Upsilon", and "mu0", on the mesh "r".
%
%The output values are the scalar field "F", its spatial derivative "H",
%the potential "V", the mass profile "M", and the energy density times the
%surface area, "muV" = 4*pi*r^2*mu.
%
%Note, if the parameters are chosen correctly, this function can produce
%any static state.  However, computing higher excited states can require
%finer meshes or a more accurate finite difference scheme than the forward
%Euler scheme used in this subroutine.

%Define Parameters

N = length(r) - 1;
dr = r(2);
omega = omegamult*Upsilon;

%Define functions

muV = zeros(1,N+1);
M = zeros(1,N+1);
V = zeros(1,N+1);
F = zeros(1,N+1);
H = zeros(1,N+1);

%Data at r=0.

muV(1) = 0;
M(1) = 0;
V(1) = V0;
F(1) = F0;
H(1) = 0;

%Integrate in space using forward Euler.

M(2) = 0;
V(2) = V(1);
F(2) = F(1);
H(2) = (Upsilon^2 - omega^2)*dr/(3*exp(2*V(1)));

for k = 2:N
    
    cv1 = 1 - 2*M(k)/r(k);
    
    muVka = (1 + omega^2/Upsilon^2*exp(-2*V(k)))*abs(F(k))^2;
    muVkb = cv1*abs(H(k))^2/Upsilon^2;
    muV(k) = 4*pi*r(k)^2*mu0*(muVka + muVkb);
    
    M(k+1) = M(k) + muV(k)*dr;
    
    Vka = (1 - omega^2/Upsilon^2*exp(-2*V(k)))*abs(F(k))^2;
    Vkb = cv1*abs(H(k))^2/Upsilon^2;
    Vkc = M(k)/r(k)^2 - 4*pi*r(k)*mu0*(Vka - Vkb);
    V(k+1) = V(k) + dr/cv1*Vkc;
    
    F(k+1) = F(k) + H(k)*dr;
    
    Hka = (Upsilon^2 - omega^2*exp(-2*V(k)))*F(k);
    Hkb = 2*H(k)*(M(k)/r(k)^2 - 1/r(k) + 4*pi*r(k)*mu0*abs(F(k))^2);
    H(k+1) = H(k) + dr/cv1*(Hka + Hkb);
    
end

cv1 = 1 - 2*M(N+1)/r(N+1);
    
muVka = (1 + omega^2/Upsilon^2*exp(-2*V(N+1)))*abs(F(N+1))^2;
muVkb = cv1*abs(H(N+1))^2/Upsilon^2;
muV(N+1) = 4*pi*r(N+1)^2*mu0*(muVka + muVkb);


end