function [lambda,U,par] = NCEKG_state(F0,N,rmax,Upsilon,mu0,state,Vlist)

%Version 1.0
%Copyright 28 December 2012 by Alan R. Parry
%Permission is granted to all to use this software for non-commercial uses
%only. Permission for commercial use must be obtained in writing from the
%author.
%
%This function computes the "state"^{th} excited state (the 0^{th} state
%corresponding to the ground state) of the EKG equations with the parameter
%values F(0)="F0", "Upsilon", "mu0", on the mesh of "N" subintervals on the
%interval [0,"rmax"].  "Vlist" is a pair of "guesses" for the V0 parameter.
%
%The output parameters are defined as follows.  "U" is a 5 row matrix
%containing the values of the functions f (row 1), p (row 2), V (row 3), M
%(row 4), and muV (row 5) of the best fitting static state.  The functions
%f, p, V, and M are as defined in the paper, muV is equal to 4pi r^2 mu,
%where mu is the energy density.  The value "lambda" is a reflectivity
%constant and is unimportant in the current setting of working with static
%states.  The set "par" has four elements.  The first two are the values of
%the asymptotic behaviors we solved the shooting problem for.  We want them
%to be close to zero.  The second two are the values of V0 and omega for
%the computed static state.
%
%This function was given a version number with Version 2.2 of the NCEKG
%software.

%Create mesh.

dr = rmax/N;
r = 0:dr:rmax;

%Compute the desired state.

[AB1,AB2,V0,omega,Hend,f,V,M,muV] = NCEKG_state_scaled(F0,r,Upsilon,mu0,state,Vlist);

%Compute the corresponding function p.

p = zeros(1,N+1);
p(1) = 1i*omega*exp(-V(1))*f(1);

for k = 2:N+1
    
    p(k) = 1i*omega*exp(-V(k))*(1 - 2*M(k)/r(k))^(-1/2)*f(k);
    
end

%Collect functions.

U(1,1:N+1) = f;
U(2,1:N+1) = p;
U(3,1:N+1) = V;
U(4,1:N+1) = M;
U(5,1:N+1) = muV;

%Compute the value of lambda that should keep the state static.

lambda = (p(N+1) + Hend)/(p(N+1) - Hend);

%Collect important parameter values.

par = [AB1,AB2,V0,omega];


end