function [omegamult,AB1,Hend,F,V,M,muV] = NCEKG_state_finder(F0,V0,r,Upsilon,mu0,state)

%Version 1.0
%Copyright 28 December 2012 by Alan R. Parry
%Permission is granted to all to use this software for non-commercial uses
%only. Permission for commercial use must be obtained in writing from the
%author.
%
%This function computes the static "state"^{th} excited state with small
%"AB1" value that has the properties F(0)="F0", V(0)="V0", "Upsilon", and
%"mu0", on the mesh "r".
%
%The output values are as follows.  "AB1" is the required end behavior on
%the function F and should be close to 0.  If omega is the frequency that
%yields the small AB1 value, then "omegamult" is defined by the equation,
%omega = omegamult*Upsilon.  "Hend" is the outermost value of the
%derivative H of the scalar field F, and is used for other purposes than
%the scope of this set of programs.  The functions, "F", "V", "M", and
%"muV" are respectively, the scalar field, potential, mass, and the energy
%density multiplied by the surface area.

%Compute parameters.

N = length(r) - 1;

%This is the accuracy parameter.  Since Matlab uses double precision (16
%significant digits) numbers, we won't be able to get much better accuracy
%than this anyway.

acc = 1e-16;

%We set the nodes one above the desired state to force the program to step
%down, we know that the nodes when omegamult = 1 will be greater than any
%state since omegamult<=1.

nodes = state + 1;
omegamult = 1;

%We set omstep to 1 because it cuts in half immediately.  We set AB1 to
%be some arbitrary value much larger than the acc value (we chose 1).

omstep = 1;
AB1 = 1;

%Compute omega that gives the corresponding state.  The loop will run until
%omstep <= 2^(-52) (i.e. approx 16 digits of accuracy), or AB1 < acc.

while and(omstep > 2^(-52), or(abs(AB1) >= acc, isequalwithequalnans(AB1,NaN)))
    
    %Cut omstep in half at the start of each step down or up procedure.
    %This parameter determines how much we change omegamult for each test.
    
    omstep = omstep/2;
    
    while nodes > state
        
        %Step down because nodes > state.
        
        omegamult = omegamult - omstep;
        omega = omegamult*Upsilon;
        
        %Solve ODEs and plot F.
        
        [F,~,~,~,~] = NCEKG_computestatic(F0,V0,omegamult,r,Upsilon,mu0);
        PlotFun(F,r);
        
        %Compute actual domain.  A lot of these solutions will have a lot
        %of static on the tail end since they are far away from a static
        %state.  The "actual" domain rejects all values after the point
        %where F > 3*F(0).  Really the static solution F should always have
        %the property F <= F(0), but this isn't always true for a numerical
        %approximation.  However, it shouldn't get hardly any bigger than
        %F(0) (certainly not triple its size), but this gives a nice comfy
        %cushion that guarantees we include the part of the mesh we want
        %and reject all of the mesh we don't.  We only compute this because
        %the only actual zeros of the functions occur on the "actual"
        %domain and we want to get an accurate count of those zeros.
        
        stp = 1;
        
        while and(abs(F(stp)) <= 3*abs(F0), stp < N+1)
            stp = stp + 1;
        end
        
        %Compute number of nodes on the actual domain.
        
        nodes = 0;
        
        for k = 2:stp
            if sign(F(k)) ~= sign(F(k-1))
                if and(F(k) ~= 0, isequal(0,isequalwithequalnans(F(k),NaN)))
                    nodes = nodes + 1;
                end
            end
        end
    end
    
    %Cut omstep in half in order to step up.
    
    omstep = omstep/2;
    
    while nodes <= state
        
        %Step up because nodes <= state.
        
        omegamult = omegamult + omstep;
        omega = omegamult*Upsilon;
        
        %Solve ODEs and plot F.
        
        [F,H,~,~,~] = NCEKG_computestatic(F0,V0,omegamult,r,Upsilon,mu0);
        PlotFun(F,r);
        
        %Compute actual domain.  See corresponding note in the stepping
        %down procedure.
        
        stp = 1;
        
        while and(abs(F(stp)) <= 3*abs(F0), stp < N+1)
            stp = stp + 1;
        end
        
        %Compute number of nodes on the actual domain.
        
        nodes = 0;
        
        for k = 2:stp
            if sign(F(k)) ~= sign(F(k-1))
                if and(F(k) ~= 0, isequal(0,isequalwithequalnans(F(k),NaN)))
                    nodes = nodes + 1;
                end
            end
        end
    end
    
    %Compute error of first asymptotic behavior.
    
    AB1 = H(N+1) + (sqrt(Upsilon^2 - omega^2) + 1/r(N+1))*F(N+1);
    
end

%Go down one more time since now nodes > state.  We cut omstep in half
%again for this last procedure.

omstep = omstep/2;
    
    while nodes > state
        
        %Step down.
        
        omegamult = omegamult - omstep;
        %omega = omegamult*Upsilon;
        
        %Solve ODEs and plot F.
        
        [F,H,V,M,muV] = NCEKG_computestatic(F0,V0,omegamult,r,Upsilon,mu0);
        PlotFun(F,r);
        
        %Compute actual domain.
        
        stp = 1;
        
        while and(abs(F(stp)) <= 3*abs(F0), stp < N+1)
            stp = stp + 1;
        end
        
        %Compute number of nodes.
        
        nodes = 0;
        
        for k = 2:stp
            if sign(F(k)) ~= sign(F(k-1))
                if and(F(k) ~= 0, isequal(0,isequalwithequalnans(F(k),NaN)))
                    nodes = nodes + 1;
                end
            end
        end
    end
    
%Compute error of first asymptotic behavior.
    
AB1 = H(N+1) + (sqrt(Upsilon^2 - omega^2) + 1/r(N+1))*F(N+1);

%Compute Hend.  This value is needed to compute the value of lambda back
%in the NCEKG_state routine, which is not important if we are only
%interested in the static state, but is important if we want to evolve the
%state using the time evolution software.

Hend = H(N+1);

end